<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>Informace o MystiQ</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Překladatelé</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>Přenosný</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Zkompilováno pomocí Qt %1</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>Zkompilováno s knihovnou libnotify %1</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>MystiQ Domovská stránka: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>Některé funkce pro zpracování zvuku poskytl SoX.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>Španělština (Španělsko)</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation>MystiQ je rozhraní GUI pro FFmpeg.</translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation>Vývojáři: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation>Název aplikace: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translatorcomment>Švédský jazyk (Švédsko)</translatorcomment>
        <translation>Švédština (Švédsko)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translatorcomment>Japonský jazyk (Japonsko)</translatorcomment>
        <translation>Japonština (Japonsko)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translatorcomment>Německý jazyk (Německo)</translatorcomment>
        <translation>Němčina (Německo)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translatorcomment>Italský jazyk (Itálie)</translatorcomment>
        <translation>Italština (Itálie)</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation>Tento program je svobodný software; můžete jej dále distribuovat a / nebo upravovat podle podmínek GNU General Public License verze 3.</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translatorcomment>Turečtina (Turecko)</translatorcomment>
        <translation>Turečtina (Turecko)</translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation>Mnoho lidí přispělo překlady. Můžete také pomoci převést převaděč videa MystiQ do svého vlastního jazyka. Návštěva </translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation> a připojte se k překladatelskému týmu.</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation>Seznam změn</translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translatorcomment>Maďarský jazyk (Maďarsko)</translatorcomment>
        <translation>Maďarština (Maďarsko)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translatorcomment>Ruský jazyk (Rusko)</translatorcomment>
        <translation>Ruština (Rusko)</translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation>Spolupracovníci: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation>Některé funkce MystiQ Video Converter byly inspirovány</translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translatorcomment>Galicijský jazyk (galicijština)</translatorcomment>
        <translation>Galicijština (Galicie)</translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation>Ikony Téma:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translatorcomment>Indonéština (Indonésie)</translatorcomment>
        <translation>Indonéština (Indonésie)</translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>O FFmpeg</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>Dostupné kodeky</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translation>FFmpef je kompletní řešení pro nahrávání, konverzi a streamování audia a videa, fungující nad několika platformami. Obsahuje kodek libav - přední knihovnu pro převod audia a videa.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>FFmpeg je freeware licencovaný pod LGPL nebo GPL.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>Chcete-li získat další informace, prosím navštivte %1 .</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>Přidej úlohy</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>Soubory ke konverzi</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>Přidat soubory.</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>Odebrat zvolené soubory.</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>Nastavení výstupu</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>Automaticky nastavit výstupní bitrate pro zmenšení velikosti výstupního souboru.</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>Automaticky nastavit bitrate audia</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>Konvertovat do</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>Cesta k výstupnímu soubotu</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>Vybrat &amp;složku</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translatorcomment>Vytvořte novou složku (např. Mystiq_output) ve složce obsahující vstupní soubory. Vložte výstupní soubory do nově vytvořené složky.</translatorcomment>
        <translation>Vytvořit &amp;novou složku ve zdrojové složce</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>Název složky</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translatorcomment>umístit výstupní soubory do stejné složky jako vstupní soubory</translatorcomment>
        <translation>Výstup do &amp;zdrojové složky</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>Prosím vyberte nejméně jeden soubor.</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>Vyberte soubory</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Multimédia</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translation>Vyberte prosím andresář</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation>Hledání souborů...</translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>Některé soubory nebyli nalezeny.</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>Složka neexistuje. Přejete si ji vytvořit?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>Vytvoření složky selhalo. Prosím vyberte jinou výstupní složku.</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation>Přidat soubory</translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation>Odstranit vybrané</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Prázdný seznam</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>Parametry konverze</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>Vypnout Audio</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>Nastavení audia</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(automaticky)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Počet kánálů</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Hlasitost</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>Vypnout video</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>Nastavení videa</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>Stejný kvantizátor jako zdroj</translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>Bez prokládání</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
    <message>
        <source> px</source>
        <translation> (sp)px</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Výška</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Oříznout</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>Čas</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>Sřih</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translatorcomment>Vystřihnout video; vyberte rozsah, který chcete převést</translatorcomment>
        <translation>Střih</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Náhled</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Rozřířené</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>Další nastavení FFmpeg</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation>Kopírování zvuku (Nekódovat)</translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation>Vložte titulky, pokud jsou k dispozici</translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation>Kopírování videa (Nekódovat)</translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation></translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation>Možnosti videa navíc</translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation>Video na černobílou</translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation>Vertikální převrácení</translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation>Horizontální převrácení</translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation>Otočte o 90 stupňů doprava</translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation>Otočte o 90 stupňů doleva</translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation>Otočit o 180 stupňů</translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>Přidávání souboru (%1 z %2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>Některé soubory nebyli rozpoznány.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>Název nového souboru</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>Prosím vložte jméno výstupního souboru.</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>Výstupní Složka</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>Chyba FFmpeg:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>Přetažením souborů sem přidejte úkoly.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>Skrýt &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>Obnovit všechny sloupce</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Cíl</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>Bitrate zvuku</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translation>Počet kanálů</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Audio kodek</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>Bitrate videa</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>Počet snímků za vteřinu</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>Kodek videa</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Průběh</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 kb/s</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>Odebírám úlohy...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Soubor existuje</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>%1 už existuje na disku nebo v seznamu úloh. Opravdu použít toto jméno výstupního souboru?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>Odebrat úlohu</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>Není možné odebrat úlohu která právě probíhá.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>Došlo k selhání</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>Chyba:%1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>Převést mezi formáty souborů</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>Převodník médií</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation>Uživatelský manuál</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translatorcomment>Střih jako v &quot;řezacím videu&quot;</translatorcomment>
        <translation>Sřih</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation>Označit jako začátek</translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation>Pokuste se začít</translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation>Výběr hry</translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation>Označit jako konec</translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation>Hledejte do konce</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>Začít konverzi.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>&amp;Konvertovat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>&amp;Přidat soubory</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>Přidat soubory pro konverzi.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Konec</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>Ukončit program.</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>S&amp;top</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>Zastavit konverzi.</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>Nastavit &amp;Parametry</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>Nastavit Parametry</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>Změnit parametry konverze vybraných souborů.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>&amp;Otevřít výstupní složku</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>Otevřete výstupní složku vybraného souboru.</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>O &amp;FFmpeg</translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>O FFmpeg</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>&amp;Odebrat vybrané</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>Odebrat všechny vybrané ze seznamu.</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translation>O&amp;debrat celý seznam</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>Odebrat celý seznam</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>Odebrat všechny dokončené ze seznamu.</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Vymazat seznam</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>Odebrat všechny soubory na seznamu.</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Opakovat</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Opakovat</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>Opakovat vybrané úlohy.</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>Opakovat &amp;všechny</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>Opakovat všechny úlohy.</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>O tomto programu</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>Změnit jméno výstupního &amp;souboru</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>Zmenít jméno výstupního souboru vybrané položky.</translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>Zmenit výstupní &amp;složku</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>Změnit výstupní složku vybrané položky.</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>Zobrazit Chybovou &amp;Hlášku</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>&amp;Kontrola Aktualizací</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translatorcomment>Vystřihnout video soubor (vyberte časový rozsah, který chcete převést)</translatorcomment>
        <translation>Střih</translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>Všechny úlohy dokončeny.</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>Není co konvertovat.</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>Konverze stále probíhá, Ukončit?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>Vyponout po dokončení všech úloh.</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>Uspat po dokončení všech úloh.</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernovat</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>Hibernovat po dokončení všech úloh.</translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>Tento program bude kontrolovat aktualizace online. Povolíte tomuto programu používat pro kontrolu aktualizací internet?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>Nepodařilo se načíst soubor předvoleb. Tato aplikace se nyní ukončí.</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>Uplynuvší čas: %1 h %2 m %3 s</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation>Prázdný &amp;Seznam</translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation>Informace o MystiQ</translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>Uživatelský Manuál</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation>&amp;Nahlásit Chybu</translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation>Nahlásit Chybu</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Darovat</translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation>Převod byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation>Převod selhal.</translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation>Podpořte MystiQ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation>MystiQ tě potřebuje</translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation>Hlášení chyb z MystiQ </translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation>Tvůj komentář:</translation>
    </message>
    <message>
        <source>Report:</source>
        <translation>Zpráva:</translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translatorcomment>Převod souboru %1-tého na soubory %2. %2 je počet souborů.</translatorcomment>
        <translation>MystiQ převádí %1/%2</translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation></translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Přeložit</translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation>Přeložit aplikaci</translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation>Nahlásit chyby</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation>Potřebujeme vaši zpětnou vazbu</translation>
    </message>
    <message>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation>Vývojový tým MystiQ Video Converter potřebuje uživatele, kteří pomocí aplikace pomáhají detekovat chyby. Pokud najdete chybu a nahlásíte ji našemu týmu, pomůže to urychlit proces opravy. Proto se můžete stát součástí našeho vývojového týmu, i když nejste vývojář. Chcete-li nahlásit chybu, můžete nám poslat e-mail s podrobným popisem nebo zadejte Github a popište problém (v tomto případě musíte mít účet GitHub).</translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translatorcomment>%1 je počítačový program</translatorcomment>
        <translation> FFmpeg nebo FFprobe %1 nebyly v systému nalezeny. Před spuštěním MystiQ zvažte jejich instalaci</translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Zkontrolujte aktualizace při spuštění programu</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>Automaticky zahájit převod po přidání souborů do seznamu.</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>Spusťte převod automaticky</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>Počet vláken které je možné použít pro konverzi</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt; &lt;p&gt; Skrýt výstupní formáty, které nejsou dostupné v aktuální instalaci ffmpeg. Doporučujeme tuto možnost zapnout, pokud si nejste jisti, že MystiQ nezjistil dostupné formáty. (vyžaduje restartování MystiQ, aby se projevilo) &lt;/p&gt; &lt;/body&gt; &lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>Skrýt nedostupné formáty (vyžaduje restartování)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>Aby se změny projevily, musíte restartovat MystiQ.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Vypnout okamžitě</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Uspat okamžitě</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernovat okamžitě</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernovat</translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>Oprarace se nepovedla: %1</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Vypínám za &lt;b&gt;%1&lt;/b&gt; sekund</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Uspávám za &lt;b&gt;%1&lt;/b&gt; sekund</translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Hibernuji za &lt;b&gt;%1&lt;/b&gt; sekund</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation>Přehrajte vybraný rozsah</translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation>Začít</translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation>Konec</translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translatorcomment>přehrajte video od času %1 do času %2. %1 a %2 jsou čas ve formátu hh: mm: ss.</translatorcomment>
        <translation>Přehrát %1~%2</translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation>Náhled videa</translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>Od začátku</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>Do konce</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>Zobrazit a &amp;uvolnit poznámky</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Zkontrolujte aktualizace při spuštění programu</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>Stahování aktualizačních informací ...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>Nelze se připojit k serveru.</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>Nepodařilo se analyzovat přijatá data.</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>Již používáte nejnovější verzi MystiQ.</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>Nastala neznámá chyba.</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>Byla vydána nová verze MystiQ!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translatorcomment>%1 je číslo verze, %2 je domovská stránka projektu</translatorcomment>
        <translation>Verze &lt;b&gt; %1 &lt;/b&gt; je k dispozici na %2.</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>Tuto verzi si můžete stáhnout pomocí odkazu:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Zkontrolovat Aktualizace</translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation>Aktuální verze, kterou používáte, je novější než verze kanálu vydání.&lt;br&gt;Proto používáte vývojový kanál.</translation>
    </message>
</context>
</TS>
